==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_feature_group/SagemakerFeatureGroupOfflineStoreConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_feature_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.505Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerFeatureGroup.SagemakerFeatureGroupOfflineStoreConfigOutputReference")
public class SagemakerFeatureGroupOfflineStoreConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected SagemakerFeatureGroupOfflineStoreConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SagemakerFeatureGroupOfflineStoreConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SagemakerFeatureGroupOfflineStoreConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDataCatalogConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig value) {
        software.amazon.jsii.Kernel.call(this, "putDataCatalogConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putS3StorageConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig value) {
        software.amazon.jsii.Kernel.call(this, "putS3StorageConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDataCatalogConfig() {
        software.amazon.jsii.Kernel.call(this, "resetDataCatalogConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDisableGlueTableCreation() {
        software.amazon.jsii.Kernel.call(this, "resetDisableGlueTableCreation", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference getDataCatalogConfig() {
        return software.amazon.jsii.Kernel.get(this, "dataCatalogConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference getS3StorageConfig() {
        return software.amazon.jsii.Kernel.get(this, "s3StorageConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig getDataCatalogConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "dataCatalogConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDisableGlueTableCreationInput() {
        return software.amazon.jsii.Kernel.get(this, "disableGlueTableCreationInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig getS3StorageConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "s3StorageConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDisableGlueTableCreation() {
        return software.amazon.jsii.Kernel.get(this, "disableGlueTableCreation", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDisableGlueTableCreation(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "disableGlueTableCreation", java.util.Objects.requireNonNull(value, "disableGlueTableCreation is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDisableGlueTableCreation(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "disableGlueTableCreation", java.util.Objects.requireNonNull(value, "disableGlueTableCreation is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_feature_group/SagemakerFeatureGroupOfflineStoreConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_feature_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.590Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerFeatureGroup.SagemakerFeatureGroupOfflineStoreConfigOutputReference")
public class SagemakerFeatureGroupOfflineStoreConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected SagemakerFeatureGroupOfflineStoreConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SagemakerFeatureGroupOfflineStoreConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SagemakerFeatureGroupOfflineStoreConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDataCatalogConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig value) {
        software.amazon.jsii.Kernel.call(this, "putDataCatalogConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putS3StorageConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig value) {
        software.amazon.jsii.Kernel.call(this, "putS3StorageConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDataCatalogConfig() {
        software.amazon.jsii.Kernel.call(this, "resetDataCatalogConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDisableGlueTableCreation() {
        software.amazon.jsii.Kernel.call(this, "resetDisableGlueTableCreation", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetTableFormat() {
        software.amazon.jsii.Kernel.call(this, "resetTableFormat", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference getDataCatalogConfig() {
        return software.amazon.jsii.Kernel.get(this, "dataCatalogConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference getS3StorageConfig() {
        return software.amazon.jsii.Kernel.get(this, "s3StorageConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig getDataCatalogConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "dataCatalogConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDisableGlueTableCreationInput() {
        return software.amazon.jsii.Kernel.get(this, "disableGlueTableCreationInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig getS3StorageConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "s3StorageConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getTableFormatInput() {
        return software.amazon.jsii.Kernel.get(this, "tableFormatInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDisableGlueTableCreation() {
        return software.amazon.jsii.Kernel.get(this, "disableGlueTableCreation", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDisableGlueTableCreation(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "disableGlueTableCreation", java.util.Objects.requireNonNull(value, "disableGlueTableCreation is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDisableGlueTableCreation(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "disableGlueTableCreation", java.util.Objects.requireNonNull(value, "disableGlueTableCreation is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getTableFormat() {
        return software.amazon.jsii.Kernel.get(this, "tableFormat", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setTableFormat(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "tableFormat", java.util.Objects.requireNonNull(value, "tableFormat is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.sagemaker_feature_group.SagemakerFeatureGroupOfflineStoreConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
